from django.test import TestCase, RequestFactory
from .models import Post, Comment, Category
from django.utils import timezone
from .views import blog_category as bc
from .views import blog_detail as bd
from .forms import CommentForm
from .apps import BlogConfig
from django.apps import apps
from django.urls import reverse
from .forms import CommentForm
from model_mommy import mommy

# Create your tests here.


class ModelTestMommy(TestCase):

    def test_category_model_mommy(self):
        cat = mommy.make(Category)
        self.assertTrue(isinstance(cat, Category))
        self.assertEqual(cat.category(), cat.name)

    def test_post_title_model_mommy(self):
        tit = mommy.make(Post)
        self.assertTrue(isinstance(tit, Post))
        self.assertEqual(tit.post_title(), tit.title)

    def test_post_body_mommy(self):
        bod = mommy.make(Post)
        self.assertTrue(isinstance(bod, Post))
        self.assertEqual(bod.post_body(), bod.body)

    def test_post_created_on_mommy(self):
        con = mommy.make(Post)
        self.assertTrue(isinstance(con, Post))
        self.assertEqual(con.post_created_on(), con.created_on)

    def test_post_last_modified_on_mommy(self):
        lon = mommy.make(Post)
        self.assertTrue(isinstance(lon, Post))
        self.assertEqual(lon.post_last_modified(), lon.last_modified)

    def test_post_categories_mommy(self):
        catp = mommy.make(Post)
        self.assertTrue(isinstance(catp, Post))
        self.assertEqual(catp.post_categories(), catp.categories)

    def test_comment_author_mommy(self):
        com = mommy.make(Comment)
        self.assertTrue(isinstance(com, Comment))
        self.assertEqual(com.comment_author(), com.author)

    def test_comment_body_mommy(self):
        comb = mommy.make(Comment)
        self.assertTrue(isinstance(comb, Comment))
        self.assertEqual(comb.comment_body(), comb.body)

    def test_comment_created_on_mommy(self):
        crtdon = mommy.make(Comment)
        self.assertTrue(isinstance(crtdon, Comment))
        self.assertEqual(crtdon.comment_created_on(), crtdon.created_on)

    def test_comment_post_mommy(self):
        cpost = mommy.make(Comment)
        self.assertTrue(isinstance(cpost, Comment))
        self.assertEqual(cpost.comment_post(), cpost.post)

    def test_blog_index_view_uses_correct_template(self):
        response = self.client.get(reverse('blog_index'))
        self.assertEquals(response.status_code, 200)
        self.assertTemplateUsed(response, 'blog_index.html')


class TestApps(TestCase):
    """docstring for TestApps"""

    def test_apps(self):
        self.assertEqual(BlogConfig.name, "blog")
        self.assertEqual(apps.get_app_config("blog").name, "blog")


class TestingTemplate(TestCase):
    """docstring for TestingTemplate"""

    def create_post(self, ptitle="only a test", pbody="yes, this is only a test", pcrtdon=timezone.now(), plastmdfd=timezone.now()):
        return Post.objects.create(title=ptitle, body=pbody, created_on=pcrtdon, last_modified=plastmdfd)

    def test_project_category_view_uses_correct_template(self):
        self.factory = RequestFactory()
        self.cv = self.create_post()
        request = self.factory.get("<category>/")
        request.cv = self.cv
        response = bc(request, 1)
        self.assertEqual(response.status_code, 200)

    def test_project_detail_view_uses_correct_template(self):
        self.factory = RequestFactory()
        self.dv = self.create_post()
        request = self.factory.get("<int:pk>/")
        request.dv = self.dv
        response = bd(request, 1)
        self.assertEqual(response.status_code, 200)



from django.shortcuts import render
from projects.models import Project


def project_index(request):
    projects = Project.objects.all()
    context = {"projects": projects}
    return render(request, "project_index.html", context)


def project_detail(request, pk):
    project = Project.objects.get(pk=pk)
    context = {"project": project}
    return render(request, "project_detail.html", context)



# Generated by Django 2.1.4 on 2018-12-16 13:45

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Project',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True,
                                        serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=100)),
                ('description', models.TextField()),
                ('technology', models.CharField(max_length=20)),
                ('image', models.FilePathField(path='/img')),
            ],
        ),
    ]



from django import forms


class CommentForm(forms.Form):
    author = forms.CharField(
        max_length=60,
        widget=forms.TextInput(attrs={
            "class": "form-control",
            "placeholder": "Your Name"
        })
    )
    body = forms.CharField(widget=forms.Textarea(
        attrs={
            "class": "form-control",
            "placeholder": "Leave a comment!"
        })
    )



from setuptools import setup, find_packages
from os import path

from io import open

here = path.abspath(path.dirname(__file__))

with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='TestDjangoPackage',
    version='1.1.4',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/KathurimaKimathi/testdjangopackage/',
    author='Kathurima Kimathi',
    author_email='kathurima@healthcloud.co.ke',

    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    keywords='sample testdjangopackage setuptools development',
    packages=find_packages(exclude=['contrib', 'docs', 'tests']),
    python_requires='>=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, <4',
    install_requires=['peppercorn', 'django', 'twine', 'sentry-sdk==0.10.1'],
    extras_require={
        'dev': ['check-manifest'],
        'test': ['coverage'],
    },
    package_data={
        'TestDjangoPackage': ['*.dat'],
    },
    scripts=['runtestblog'],
)



from django.contrib import admin
from blog.models import Post, Category


class PostAdmin(admin.ModelAdmin):
    pass


class CategoryAdmin(admin.ModelAdmin):
    pass


admin.site.register(Post, PostAdmin)
admin.site.register(Category, CategoryAdmin)
